#[non_exhaustive]pub enum PluginError {
IncompatibleApi {
plugin: String,
built_for: u32,
host: u32,
},
DuplicatePlugin {
id: String,
},
Conflict {
capability: Capability,
existing: String,
plugin: String,
},
InvalidName {
plugin: String,
name: String,
},
Failed {
plugin: String,
message: String,
},
Other(String),
}Expand description
Why a plugin could not be added, or a renderer failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncompatibleApi
The plugin was built for another PLUGIN_API_VERSION.
DuplicatePlugin
A plugin with this id is already registered.
Conflict
Two plugins registered the same capability under the same name.
InvalidName
An id or capability name is empty or uses characters other than
lowercase letters, digits, -, _ and ..
Failed
The plugin’s own register failed.
Other(String)
A plugin-defined error, for example from a SourceRenderer.