#[non_exhaustive]pub struct ComponentContext<'a> {
pub console: &'a Console,
pub width: usize,
pub height: usize,
}Expand description
What a component renders and handles events for: the console to render with, and the space it has.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.console: &'a Consolewidth: usizeColumns available.
height: usizeRows available; a taller view is cut off at the bottom.
Implementations
Sourceimpl<'a> ComponentContext<'a>
impl<'a> ComponentContext<'a>